/*
 *  swimacfwupdate.h
 *  swimac
 *
 *  Created by Mark de Jong on 3/17/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWIMACFWUPDATE__
#define __SWIMACFWUPDATE__

#ifdef __cplusplus
extern "C"	{
#endif

#include "swimacdatatypes.h"
#include "swimacrcodes.h"
	
#pragma mark FWU = FirmWare Update
#pragma mark -
#pragma mark -- FWU Data Structures and Defines

#pragma mark FWU Flash Image Info

/////////////////////////////////////////////////////
////////// Flash Image Info//////////////////////////
/////////////////////////////////////////////////////
#define FLASH_IMAGE_STRING_MAX_LEN					84
#define FLASH_IMAGE_STRING_TYPE_RELEASE_DATE_LEN	8
#define FLASH_IMAGE_STRING_TYPE_PRODUCT_TYPE_LEN	4
#define FLASH_IMAGE_STRING_TYPE_IMAGE_SIZE_LEN		4

#define MAX_NUM_FLASH_IMAGE_STRINGS					4


typedef enum SWI_TYPE_FLASH_IMAGE_STRING_TYPE
{
	FLASH_IMAGE_STRING_TYPE_VERSION_CDMA_CWE	= 0,
	FLASH_IMAGE_STRING_TYPE_VERSION_CDMA_USBD	= 1,
	FLASH_IMAGE_STRING_TYPE_VERSION_UMTS_CWE	= 2,
	FLASH_IMAGE_STRING_TYPE_VERSION_UMTS_USBD	= 3,
	FLASH_IMAGE_STRING_TYPE_VERSION_SWOC		= 4,
	FLASH_IMAGE_STRING_TYPE_RELEASE_DATE		= 5,
	FLASH_IMAGE_STRING_TYPE_PRODUCT_TYPE		= 6,
	FLASH_IMAGE_STRING_TYPE_IMAGE_SIZE			= 7
} SWI_TYPE_FLASH_IMAGE_STRING_TYPE;


typedef struct SWI_STRUCT_FLASH_IMAGE_STRING
{
	SWI_U8	nType;				//SWI_TYPE_FLASH_IMAGE_STRING_TYPE
	SWI_U8	nLength;			//Length of string in text array (not NULL terminated) 
	SWI_U8	text[FLASH_IMAGE_STRING_MAX_LEN];
	SWI_U32	nImageSize;
} SWI_STRUCT_FLASH_IMAGE_STRING;
  
typedef struct SWI_STRUCT_FLASH_IMAGE_INFO
{
  SWI_U32 sizeStruct;
  SWI_U8  nResult;          //0 = success, 1 = unsupported image type, 2 = image not found
  SWI_U8  ImageType[4];     //QCOM, USBD, APPL, SWOC, BOOT
  SWI_U8  nNumImageStrings; //number of sImageStrings in sImageStrings array
  SWI_STRUCT_FLASH_IMAGE_STRING sImageStrings[MAX_NUM_FLASH_IMAGE_STRINGS]; //use nNumImageStrings to determine number of existing Imagestrings in array.
} SWI_STRUCT_FLASH_IMAGE_INFO;

typedef struct SWI_STRUCT_FLASH_INFO
{
	char	flashName[5];
	char	flashVersion[84];
	char	flashDate[9];
	SWI_U32	flashSize;
} SWI_STRUCT_FLASH_INFO;

#pragma mark FWU File Structures

/////////////////////////////////////////////////////////////////////////////////
//

#define SWI_FILENAME_LEN					8
#if defined(CNS_FILENAME_LEN) && SWI_FILENAME_LEN != CNS_FILENAME_LEN
#error CNS and SWI definition mismatch
#endif

typedef enum SWI_ENUM_UpdateFromFileStatus
{
	FILE_UPDATE_SUCCESS,
	FILE_NOT_FOUND,
	FILE_INCORRECT_SIZE,
	FILE_INCORRECT_HEADER,
	FILE_INVALID_REVISION,
} SWI_ENUM_UpdateFromFileStatus;

typedef struct SWI_STRUCT_NVUpdateFromFile
{
	SWI_U32	sizeStruct;		// size of this structure
	SWI_ENUM_UpdateFromFileStatus	nStatus;	// Operation return status
	SWI_U32	nItemsUpdated;					// Number of items updated
	SWI_U32	nItemsSkipped;					// Number of items not updated
} SWI_STRUCT_NVUpdateFromFile;

typedef struct SWI_STRUCT_NVUpdateFromFileSetReq
{
  SWI_U32	sizeStruct;
  SWI_U8	filename[SWI_FILENAME_LEN];  
} SWI_STRUCT_NVUpdateFromFileSetReq;

typedef enum SWI_ENUM_NVStore_Operation
{
	NVStore_Backup_All,
	NVStore_Restore_All,
	NVStore_Backup,
	NVStore_Restore
} SWI_ENUM_NVStore_Operation;

typedef enum SWI_ENUM_NVStore_Category
{
	NVCategory_Factory_Settings,
	NVCategory_OEM_Settings,
	NVCategory_User_Settings,
	NVCategory_All_Settings,
} SWI_ENUM_NVStore_Category;

typedef struct SWI_STRUCT_NVRAMStore
{
	SWI_U32	sizeStruct;		// size of this structure
	SWI_U8	op_status;
	SWI_U8	op;					/* nvop_enum */ 
	SWI_U8	category;			/* nvcategory_enum */        
	SWI_U32	items_stored;
	SWI_U32	items_skipped;
	SWI_U32	zero_length_items;	/* For backup only */
	SWI_U8	unused[23];
} SWI_STRUCT_NVRAMStore;


#pragma mark FWU Notifications

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_NOTIF_FW_TYPE - firmware download states 
//
// Purpose:	This enumeration contains all of the firmware download states.  
//
// Members:	FW_INIT				- Initializing and opening the specified image file to 
//			download.	
//	
//			FW_INIT_ERR			- initializing error occurred
//
//			FW_SOFT_RESET		- Resetting the card
//
//			FW_SOFT_RESET_ERR	- Timeout expired.  No response from the 
//			modem was received.
//
//			FW_START_REQ		- Sending the Start Firmware Download request
//
//			FW_START_REQ_ERR	- Firmware download is already in progress.
//			File could not be read.  Modem returned an error
//
//			FW_FILE_ERR			- file error occurred
//
//			FW_DWN				- firmware download packets being sent
//
//			FW_DWN_ERR			- Firmware download is already in progress
//			File could not be read.  Modem returned an error
//	
//			FW_CHKSUM			- Verifying the check sum
//
//			FW_CHKSUM_ERR		- Firmware download is already in progress.  Modem 
//			returned an error
//
//			FW_FLASH			- Sending the Program Flash request (Application 
//			only)
//
//			FW_FLASH_ERR		- Firmware download is already in progress
//
//			FW_LAUNCH_FRAG		- Sending the Launch Fragment request (Bootloader 
//			only)
//
//			FW_LAUNCH_FRAG_ERR	- Firmware download is already in progress
//
//			FW_RESET			- Firmware reset
//
//			FW_RESET_ERR		- Firmware reset error occurred
//
//			FW_DONE				- Firmware download complete
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	FW_INIT,			//0
	FW_INIT_ERR,
	FW_SOFT_RESET,
	FW_SOFT_RESET_ERR,
	FW_START_REQ,
	FW_START_REQ_ERR,
	FW_FILE_ERR,
	FW_DWN,
	FW_DWN_ERR,
	FW_CHKSUM,
	FW_CHKSUM_ERR,		// 10
	FW_FLASH,
	FW_FLASH_ERR,
	FW_LAUNCH_FRAG,
	FW_LAUNCH_FRAG_ERR,
	FW_RESET,
	FW_RESET_ERR,
	FW_DONE,

	FW_GROUP_START,
	FW_GROUP_ERR,
	FW_GROUP_DONE,		// 20

	FW_PARSE_START,
	FW_PARSE_ERR,
	FW_PARSE_DONE,

	FW_PRL_START,
	FW_PRL_ERR,
	FW_PRL_DONE,
	
	FW_ERI_START,
	FW_ERI_ERR,
	FW_ERI_DONE,
	
	FW_EFS_START,		// 30
	FW_EFS_ERR,
	FW_EFS_DONE,
	
	FW_PRINVM_START,
	FW_PRINVM_ERR,
	FW_PRINVM_DONE,
	
	FW_SD_CARD_EJECT,
	FW_SD_CARD_ERR,
	
	//HACKISH cause doenst really go here...  bleh
	FW_AT_CMD,
	FW_AT_CMD_ERR,
	
	FW_EXTERNAL_ERR,

} SWI_NOTIF_FW_TYPE;

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_FWDWN - firmware download type 
//
// Purpose:	This enumerates the image type to download.
//
// Members:	FW_DWN_APP			- application
//
//			FW_DWN_BOOT			- bootloader
//
//			FW_DWN_APP_MP		- MP application download over serial interface
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	FW_DWN_APP,
	FW_DWN_BOOT,
	FW_DWN_APP_MP,
	FW_DWN_BOOT_MP,

	FW_DWN_GROUP,

	FW_DWN_QCOM_IMAGE,
	FW_DWN_BOOT_IMAGE,
	FW_DWN_APPL_IMAGE,
	FW_DWN_SWIFW_IMAGE,
	FW_DWN_SWOC_IMAGE,

	FW_DWN_PRL,
	FW_DWN_ERI,
	FW_DWN_EFS,
	FW_DWN_PRINVM,
	FW_DWN_DLEX,
	FW_DWN_FILE

} SWI_TYPE_FWDWN;

#pragma mark FWU Download Structure

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_FWDWN - firmware download type 
//
// Purpose:	This enumerates the image type to download.
//
// Members:	FW_DWN_APP			- application
//
//			FW_DWN_BOOT			- bootloader
//
//			FW_DWN_APP_MP		- MP application download over serial interface
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
typedef enum
{
	FW_DWN_UPGRADE,
	FW_DWN_DOWNGRADE,
	FW_DWN_REFLASH,
	
} SWI_FWDWN_DIRECTION;


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_FwDownload - Firmware Update Status
//
// Purpose:	This structure reports on the status of the current firmware
//			update via notification.
//
// Members:	fuState - state of firmware update (FW_INIT, FW_DWN, etc. -- see SWI_NOTIF_FW_TYPE)
//			fuCurrentBlock - block number being processed
//			fuTotalBlocks - total blocks to process
//			fuErrorCode - an error
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
typedef struct SWI_STRUCT_FU_Status
{
	SWI_U32				fuType;
	SWI_TYPE_FWDWN		fuDownloadType;
	SWI_U8				*fuPRISKU;
	SWI_U8				*fuPRIDataVersion;
	SWI_U8				*fuLabel;
	SWI_U8				*fuDownloadPath;
	SWI_U8				*fuDownloadDate;
	SWI_U8				*fuDownloadVersion;
	SWI_U32				fuCurrentBlock;
	SWI_U32				fuTotalBlocks;
	SWI_U32				fuErrorCode;
} SWI_STRUCT_FU_Status;

#pragma mark -- FWU Configuration Parsing

typedef struct SWI_STRUCT_UpdateFromConfig
{
	bool	bHeader;
	char	*sHeader;
	char	*sUpdatePath;

	char	*sVersion;
	char	*sPRISKU;		// all pri sku values
	SWI_U16	nPRISKUCount;	// how many sku values are there
	char	**sPRISKUList;	// an array of possible sku values
	char	*sPRIDataVersion;

	bool	bAppFWUpdate;
	bool	bFORCEAppFWUpdate;
	char	*sAppFWVersion;
	char	*sMinAppFWVerForFieldUpgrade;
	char	*sAppFWLabel;
	char	*sAppFWFile;
	
	SWI_U16	pkgMajorVersion;	
	SWI_U16	pkgMinorVersion;
	SWI_U8	pkgVariantVersion;

	bool	bQCBootFWUpdate;
	bool	bFORCEQCBootFWUpdate;
	char	*sQCBootFWLabel;
	char	*sQCBootFWFile;

	bool	bBootFWUpdate;
	bool	bFORCEBootFWUpdate;
	char	*sBootFWLabel;
	char	*sBootFWFile;

	bool	bPRLUpdate;
	char	*sPRLLabel;
	char	*sPRLFile;

	bool	bERIUpdate;
	char	*sERILabel;
	char	*sERIFile;

	bool	bEFSUpdate;
	SWI_U16	nEFSFileCount;
	char	**sEFSLabels;
	char	**sEFSFiles;

	bool	bNVUpdate;
	char	*sNVUpdateLabel;
	char	*sNVUpdateFile;

	bool	bSWIFWUpdate;
	bool	bFORCESWIFWUpdate;
	char	*sSWIFWLabel;
	char	*sSWIFWFile;

	bool	bSWoCFWUpdate;
	char	*sSWoCFWLabel;
	char	*sSWoCFWFile;

	bool	bOMADMTreeUpdate;

	SWI_U16	modemPID;

} SWI_STRUCT_UpdateFromConfig;

typedef struct SWI_STRUCT_ModemVersions
{
		// Product id. "23" appears to be compass
	SWI_U16	productID;

		// Firmware version (usually same as "appl" image)
	SWI_U16	fwMajorVersion;	
	SWI_U16	fwMinorVersion;
	SWI_U8	fwVariantVersion;

		// PRI major and minor versions
		// may be swapped; use these for display only
		// typical display format:
		//		"%03d.%03d", priMajorVersion, priMinorVersion
	SWI_U8	priMajorVersion;
	SWI_U8	priMinorVersion;

		// PRISKU
	SWI_U32 priSKU;

		// PRL version
	SWI_U16 prlVersion;

		// ERI version
	SWI_U16 eriVersion;
} SWI_STRUCT_ModemVersions;

typedef struct SWI_STRUCT_VersionInfo
{
		// PackageName: C597_01.49_00_sprint_cd_014.009_000
	char	*sPackageName;

		// SWPIVersion: 1.1
		// FieldUse: No
		// FactoryUse: Yes
		// sku: 11178
		// carrierID: 2

		// productID: 23
	SWI_U16	productID;

		// FWVersion: 01.49
		// min_app_fw_ver: 1.30.0
		// prlFileVersion: 60711
		// prlUpgradeFlag: 1
		// eriFileVersion: 0002
		// config: sprint
		// config_version: 014.009
		// distributorID: 1
		// package_version: 000
		// product_variant: C597
		// flash_bin_version: 01.49_00 
		// package_make_version: 
		// CCTVersion: 6.54.1
		// flashCDMAVer: 1.11
		// SWOCVersion: CDPC_00001_02.04.07
		// SWOCFieldEnable: No
		// SWOCDetails_cdpc: 00001

		// SWOCDetails_cd_version: 02.04.07
	char	*sSWOCDetails_cd_version;

		// SWOCDetails_description: SmithMicro SCM 1.12.0015.0 (C597 RC5); Mac SmartView 1.81.0025.0 (RC5)
		// SWOCDetails_OS1_sipc: 0006
		// SWOCDetails_OS1_siVer: 0015
		// SWOCDetails_OS1_sipcDesc: Sprint Connection Manager (SmithMicro)
		// SWOCDetails_OS1_proj: PCTel-SCM
		// SWOCDetails_OS1_uiVer: 1.12.0015.0
		// SWOCDetails_OS2_sipc: 1106
		// SWOCDetails_OS2_siVer: 0025
		// SWOCDetails_OS2_sipcDesc:Sprint Connection Manager (SmithMicro) Mac
		// SWOCDetails_OS2_proj: PCTel-SCM_MacOSX
		// SWOCDetails_OS2_uiVer: 1.81.0025.0
} SWI_STRUCT_VersionInfo;

typedef struct SWI_STRUCT_FWUpgradeVersions
{
	SWI_STRUCT_UpdateFromConfig	package;
	SWI_STRUCT_ModemVersions	modem;
	SWI_STRUCT_VersionInfo		version;
	
} SWI_STRUCT_FWUpgradeVersions;

#pragma mark -
#pragma mark -- SWI FWU Functions

// SWI_RCODE SwiGetBootAndHoldMode( bool *pbBootAndHold, SWI_U32 timeout );			// Implemented in swimacapi.c
// SWI_RCODE SwiSetBootAndHoldModeWithTimeout( SWI_U32 timeout );					// Implemented in swimacapi.c


//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiNVRAMBackup - Back up the User Settings in NVRAM
//
// Purpose:	
//
// Parameters:
//
//			operation - 0x02 = Perform a backup of NV items. Currently, this is the
//				only operation supported.
//
//			backupType - 0x02 = Backup user settings. Currently, this is the
//				only backup type supported.
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiNVRAMBackup( SWI_U8 operation, SWI_U8 backupType, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiFirmwareDownloadWithTimeout - to download firmware to the modem
//
// Purpose:	This function is used to download firmware to the modem.
//
//			The firmware download process is automatic:
//
//			The modem is reset.
//			The firmware is downloaded to the modem.  Firmware download status is
//			provided by the firmware download notification.
//			The modem is reset once complete to restart the modem.
//			
// Parameters:
//
//			szFileName[IN]:		name of file to download
//
//			eType[IN]:			type of file to download (bootloader or application)
//
//			timeout[IN]			Function timeout in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The modem is reset at the beginning and end of the firmware download process.  
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiFirmwareDownloadWithTimeout( SWI_LPCTSTR szFileName, SWI_TYPE_FWDWN eType, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiFirmwareDownload - to download firmware to the modem
//
// Purpose:	Convenience function that calls SwiFirmwareDownloadWithTimeout with
//			a timeout of 3000 (Windows code: SwiCwe1xrtt.h)
//
//			See: SwiFirmwareDownloadWithTimeout for more details.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiFirmwareDownload( SWI_LPCTSTR szFileName, SWI_TYPE_FWDWN eType );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiFirmwareDownloadUsingDictionaryWithTimeout - to download firmware to the modem
//
// Purpose:	This function is used to download firmware to the modem.
//
//			The firmware download process is automatic:
//
//			The modem is reset.
//			The firmware is downloaded to the modem.  Firmware download status is
//			provided by the firmware download notification.
//			The modem is reset once complete to restart the modem.
//			
// Parameters:
//
//			configDictionary[IN]:	dictionary containing firmware download "parameters"
//
//			eType[IN]:				type of file to download (bootloader or application)
//
//			timeout[IN]				Function timeout in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The modem is reset at the beginning and end of the firmware download process.  
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiFirmwareDownloadUsingDictionaryWithTimeout( CFMutableDictionaryRef configDictionary, SWI_TYPE_FWDWN eType, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetFlashImageInfo -  Retrieves the modem Flash Image information
//
// Purpose:     This function retrieves the flash image information for any of the
//              individual CWE images stored in the modem's flash memory.
//
// Parameters:  pszImageName[In] 	      4 char ASCII image name <QCOM,BOOT,APPL,USBD,SWOC>, Not Null terminated
//              psImageInfo[Out]        Contains image info
//              
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetFlashImageInfo( SWI_U8 *pszImageName, SWI_STRUCT_FLASH_IMAGE_INFO *psImageInfo, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetFlashInfo -  Retrieves the modem Flash Image information
//
// Purpose:     This is a convenience function that calls SwiGetFlashImageInfo and
//				parses the info into a more manageble struct (SWI_STRUCT_FLASH_INFO)
//
// Parameters:  pszImageName[In]		image name <QCOM,BOOT,APPL,USBD,SWOC>, (null terminated string)
//              psImageInfo[Out]        Contains image info
//              
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetFlashInfo( SWI_U8 *pszImageName, SWI_STRUCT_FLASH_INFO *imageInfo, SWI_U32 timeout );

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiFirmwareDownload - Update NV from EFS file.
//
// Purpose:	Force the modem to perform a NV upgrade from a file written into the 
//			modem's EFS.
//
// Parameters:
//
//			pNVUpdateFromFile[IN]:	Pointer to set and respodence information
//			timeout[IN]:	Function timeout in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiNVUpdateFromFile( SWI_STRUCT_NVUpdateFromFileSetReq *pNVUpdateFromFile, SWI_U32 timeout );

////////////////////////////////////////////////////////////////////////////////
//
//	Function:	SwiCollectVersionInfoToStruct
//
//	Purpose:	Collect version info from the modem and the (potential) upgrade
//				package.
//
//	Parameters:	upgradePackage[IN]		path to upgrade package file or folder
//				upgradeVersions[OUT]	returned versions
//
//	Return:		SWI_RCODE
//
////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiCollectVersionInfoToStruct( char *upgradePackage, SWI_STRUCT_FWUpgradeVersions *upgradeVersions );

////////////////////////////////////////////////////////////////////////////////
//
//	Function:	SwiCollectVersionInfo
//
//	Purpose:	Collect version info from the modem and the (potential) upgrade
//				package.
//
//	Parameters:	upgradePackage[IN]		path to upgrade package file or folder
//				configDictionary[OUT]	dictionary to populate
//
//	Return:		SWI_RCODE
//
////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiCollectVersionInfo( char *upgradePackage, CFMutableDictionaryRef *configDictionary );

// Unused (windows related?) calls
//
//SWI_RCODE SwiSetNDISPrefMode(SWI_NDIS_PREF_MODE eNDISPrefMode);
//SWI_RCODE SwiRegisterDeviceArrivalEvent( SWI_LPTSTR szArrivalEventName );
//SWI_RCODE SwiDeRegisterDeviceArrivalEvent();
//SWI_RCODE SwiDeviceArrivalGateway( bool bGatewayState );

#ifdef __cplusplus
}
#endif

#endif __SWIMACFWUPDATE__
