	/*
 *  swimacpst.h
 *  swimac
 *
 *  Created by Russ Winsper on 12/30/06.
 *  Copyright 2006 - 2007 Sierra Wireless. All rights reserved.
 *
 */

#ifndef __SWIMACPST__
#define __SWIMACPST__

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"

// String lengths for SwiPstGetWarDateCode
#define LENGTH_NvWdcDate			5	// Warranty date
#define LENGTH_NvWdcExtra			3	// Extra date
#define	LENGTH_NvBannerName			40	// SwiPstGetDisplayBannerName

/* types for CNS_HDRSCP_SUBTYPE_CUSTOM_CONFIG_I */
/* Protocol subtype selection - bitmask define */
#define CNS_HDRSCP_PROT_SUBTYPE_SUB2_PHYS_LAYER_BIT		0x00000001	/* Bit 0: Subtype 2 Physical Layer */
#define CNS_HDRSCP_PROT_SUBTYPE_ENH_CMAC_BIT			0x00000002	/* Bit 1: Enhanced CCMAC           */
#define CNS_HDRSCP_PROT_SUBTYPE_ENH_AMAC_BIT			0x00000004	/* Bit 2: Enhanced ACMAC           */
#define CNS_HDRSCP_PROT_SUBTYPE_ENH_FMAC_BIT			0x00000008	/* Bit 3: Enhanced FTCMAC          */
#define CNS_HDRSCP_PROT_SUBTYPE_RMAC_SUB3_BIT			0x00000010	/* Bit 4: Subtype 3 RTCMAC         */
#define CNS_HDRSCP_PROT_SUBTYPE_RMAC_SUB1_BIT			0x00000020	/* Bit 5: Subtype 1 RTCMAC         */
#define CNS_HDRSCP_PROT_SUBTYPE_ENH_IDLE_BIT			0x00000040	/* Bit 6: Enhanced Idle            */
#define CNS_HDRSCP_PROT_SUBTYPE_GMMCDP_BIT				0x00000080	/* Bit 7: Generic MultiMode Capab Disc prot */
/* bits 8 through 31 are reserved */
typedef SWI_U32 cns_hdrscp_prot_subtype_enable_mask_type; /* only assign the above values */

/* Broadcast protocol negotiation bitmask define */
#define CNS_HDRSCP_BCMCS_GEN_BROADCAST_IS_ENBLD_BIT		0x00000001	/* Bit 0: Enable Generic broadcast (subtype 1) */
/* bits 1 through 31 are reserved */
typedef SWI_U32 cns_hdrscp_bcmcs_enable_mask_type; /* only assign the above values */

/* Application subtypes bitmask define */
#define CNS_HDRSCP_APP_SUBTYPE_ENABLE_MFPA_BIT			0x00000001	/* Bit 0: SN Multiflow Packet Application */
/* bits 1 through 31 are reserved */
typedef SWI_U32 cns_hdrscp_app_subtype_enable_mask_type; /* only assign the above values */

typedef struct
{
	SWI_U16	custom_config_is_active;
	cns_hdrscp_prot_subtype_enable_mask_type  prot_subtype_mask;
	cns_hdrscp_bcmcs_enable_mask_type			bcmcs_subtype_mask;
	cns_hdrscp_app_subtype_enable_mask_type   app_subtype_mask;
} __attribute__((packed)) CNS_HDRSCP_subtype_custom_config_type_Packed;

/* This is data structure for CNS_HDRSCP_SUBTYPE_CUSTOM_CONFIG_I item. 
     To be used with CNS_PST_NV object ID. */
typedef struct
{
	SWI_U32	sizeStruct;     // size of this structure
	SWI_U16   custom_config_is_active;
	cns_hdrscp_prot_subtype_enable_mask_type  prot_subtype_mask;
	cns_hdrscp_bcmcs_enable_mask_type			bcmcs_subtype_mask;
	cns_hdrscp_app_subtype_enable_mask_type   app_subtype_mask;
} CNS_HDRSCP_subtype_custom_config_type;

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Commit_ErrorMask - Activation Commit error mask enumeration
//
// Purpose:     This identifies the possible bits in the
//				failure mask field returned by SwiPstLock
//
// Memnbers:	SWI_COMMIT_ERRMASK_NONE			- No error
//              SWI_COMMIT_ERRMASK_MDN			- MDN not set
//              SWI_COMMIT_ERRMASK_IMSI			- IMSI not set
//              SWI_COMMIT_ERRMASK_USERIDPW		- No User ID/Password
//              SWI_COMMIT_ERRMASK_DATE			- No Provisioning Date
//              SWI_COMMIT_ERRMASK_NAMORDER		- NAM profile index out of sequence
//												  (NAM 0 must always be provisioned
//												   first)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Commit_ErrorMask
{
	SWI_COMMIT_ERRMASK_NONE			= 0x00000000,
	SWI_COMMIT_ERRMASK_MDN			= 0x00000001,
	SWI_COMMIT_ERRMASK_IMSI			= 0x00000002,
	SWI_COMMIT_ERRMASK_USERIDPW		= 0x00000004,
	SWI_COMMIT_ERRMASK_DATE			= 0x00000008,
	SWI_COMMIT_ERRMASK_NAMORDER		= 0x00000010,
};

typedef enum 
{
	SWI_NV_PREF_OP_MODE_CdmaThenAnalog,     // Not supported
	SWI_NV_PREF_OP_MODE_CdmaOnly,           // 2G CDMA
	SWI_NV_PREF_OP_MODE_AnalogThenCdma,     // Not supported
	SWI_NV_PREF_OP_MODE_AnalogOnly,         // Not supported    
	SWI_NV_PREF_OP_MODE_Automatic,          // Automatic
	SWI_NV_PREF_OP_MODE_Emergency,          // Emergency
	SWI_NV_PREF_OP_MODE_RestrictHomeOnly,   // Restrict Home Only
	SWI_NV_PREF_OP_MODE_PcsCdmaOnly,        // 1900Mhz CDMA Only
	SWI_NV_PREF_OP_MODE_CellCdmaOnly,       // 800Mhz CDMA Only
	SWI_NV_PREF_OP_MODE_Cdma1xOnly,         // 1xRTT CDMA Only
	SWI_NV_PREF_OP_MODE_CdmaEvdoOnly,       // 1xEVDO CDMA Only
} SWI_TYPE_NvPrefOpMode;


//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetEVDOSCPSettings
//
// Purpose:	This function ... <DESCRIPTION OF SwiGetEVDOSCPSettings() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiGetEVDOSCPSettings() succeeded.
//		SWI_RCODE_FAILED - SwiGetEVDOSCPSettings() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiGetEVDOSCPSettings() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiGetEVDOSCPSettings() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiGetEVDOSCPSettings>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetEVDOSCPSettings(SWI_U8 *pbUsesSCP ,SWI_U16 *pwCustCfgActive, SWI_U32 *pdwProtMask, 
                                        SWI_U32 *pdwBCMCSMask, SWI_U32 *pdwAppMask, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetImsiMS1
//
// Purpose:	This function ... <DESCRIPTION OF SwiPstGetImsiMS1() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiPstGetImsiMS1() succeeded.
//		SWI_RCODE_FAILED - SwiPstGetImsiMS1() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiPstGetImsiMS1() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiPstGetImsiMS1() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiPstGetImsiMS1>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetImsiMS1(const SWI_U16 Nam, SWI_U32 *IMSI, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetImsiMS2
//
// Purpose:	This function ... <DESCRIPTION OF SwiPstGetImsiMS2() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiPstGetImsiMS2() succeeded.
//		SWI_RCODE_FAILED - SwiPstGetImsiMS2() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiPstGetImsiMS2() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiPstGetImsiMS2() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiPstGetImsiMS2>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetImsiMS2(const SWI_U16 Nam, SWI_U16 *IMSI, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetImsi1112
//
// Purpose:	This function ... <DESCRIPTION OF SwiPstGetImsi1112() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiPstGetImsi1112() succeeded.
//		SWI_RCODE_FAILED - SwiPstGetImsi1112() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiPstGetImsi1112() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiPstGetImsi1112() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiPstGetImsi1112>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetImsi1112(const SWI_U16 Nam, SWI_U16 *Digits1112, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetImsiMcc
//
// Purpose:	This function ... <DESCRIPTION OF SwiPstGetImsiMcc() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiPstGetImsiMcc() succeeded.
//		SWI_RCODE_FAILED - SwiPstGetImsiMcc() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiPstGetImsiMcc() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiPstGetImsiMcc() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiPstGetImsiMcc>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetImsiMcc(const SWI_U16 Nam, SWI_U16 *Mcc, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetTermSid
//
// Purpose:	This function ... <DESCRIPTION OF SwiPstGetTermSid() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiPstGetTermSid() succeeded.
//		SWI_RCODE_FAILED - SwiPstGetTermSid() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiPstGetTermSid() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiPstGetTermSid() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiPstGetTermSid>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetTermSid(const SWI_U16 Nam, SWI_U16 *TermSidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstSetTermSid
//
// Purpose:	This function ... <DESCRIPTION OF SwiPstSetTermSid() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiPstSetTermSid() succeeded.
//		SWI_RCODE_FAILED - SwiPstSetTermSid() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiPstSetTermSid() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiPstSetTermSid() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiPstSetTermSid>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetTermSid(const SWI_U16 Nam, const SWI_U16 TermSidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetTermNid
//
// Purpose:	This function ... <DESCRIPTION OF SwiPstGetTermNid() GOES HERE>
//
// Parameters:
//
//		ARG 1 [IN|OUT]: ARG 1 DESCRIPTION
//
//		ARG 2 [IN|OUT]: ARG 2 DESCRIPTION
//
//		ARG 3 [IN|OUT]: ARG 3 DESCRIPTION
//
// Return:	SWI_RCODE_OK - SwiPstGetTermNid() succeeded.
//		SWI_RCODE_FAILED - SwiPstGetTermNid() failed.
//		SWI_RCODE_SYSTEM_ERROR - SwiPstGetTermNid() generated a system error.
//		SWI_RCODE_REQUEST_TIMEOUT - SwiPstGetTermNid() timed out.
//
//		<FILL IN OTHER POSSIBLE RETURN CODES BELOW>
//
//		See SWI_RCODE for other error return codes
//
// Notes:	<SPECIAL NOTES REGARDING SwiPstGetTermNid>
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetTermNid(const SWI_U16 Nam, SWI_U16 *TermNidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:   SwiPstSetTermNid   
//
// Purpose: Set the Foreign NID registration setting.
//				      
// Parameters:  Nam[IN]             Nam Index
//              TermNidEnable[IN]   Foreign NID registration setting (0 = disabled, 1 = enabled)
//              timeout[IN]         Api timeout
//
// Return:      See SwiRcodes.h
//              
// Notes:       
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetTermNid(const SWI_U16 Nam, const SWI_U16 TermNidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetNamName
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetNamName(const SWI_U16 Nam, SWI_LPCTSTR pszNamName, SWI_U32 length, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipPrereRrqTime
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipPrereRrqTime(SWI_U16* pRereg, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipQcDrsOpt
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipQcDrsOpt(SWI_U16* pActive, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipRetries
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipRetries(SWI_U16* pRetries, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipRetryInt
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipRetryInt(SWI_U16* pInterval, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipRrqIfTfrk
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipRrqIfTfrk(SWI_U16* pReregistration, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMip2002BisMnHaAuth
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMip2002BisMnHaAuth(SWI_U16* pRfc2002, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipEnableProf
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipEnableProf(SWI_STRUCT_MipEnabled* sMipEnabled, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstSetDsMipEnableProf
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetDsMipEnableProf(SWI_STRUCT_MipEnabled* sMipEnabled, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiGetGeneralFeatureSupport 
//
// Purpose: Get the device's General Feature support capabilities. 
//
// Parameters:  pMask[OUT]                   Bitmask of capability settings
//              timeout[IN]                  Api timeout
//
// Return:      See SwiRcodes.h
//              
// Notes:   This functionality is not support on all devices. A successful return indicates the
//          functionality exists.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetGeneralFeatureSupport(SWI_U32 *pMask, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetCurrentNam - Get active NAM
//
// Purpose:     This function returns the currently active NAM
//              index number.
//
// Parameters:  CurrentNam[OUT]         The index (base 0) of the currently
//                                      active NAM account profile.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This account profile is used for all call connections.
//              Use SwiPstSetCurrentNam to change the
//              active account.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetCurrentNam(SWI_U16 *CurrentNam, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetCurrentNam - Set active NAM
//
// Purpose:     This function sets the index to a NAM account
//              profile to make the active account for connec-tions
//              and other queries.
//
// Parameters:  CurrentNam[IN]          Index (base 0) to set as the
//                                      currently active NAM account
//                                      profile. See SwiGetNamInfo.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The modem must be reset via SwiResetModem to
//              have the change take effect.
//
//              The current setting can be read using
//              SwiPstGetCurrentNam.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetCurrentNam(const SWI_U16 CurrentNam, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetSystemPref - Get prefered service
//
// Purpose:     This function returns the setting of the CDMA
//              "preferred service" for a specified NAM account
//              profile.
//
// Parameters:  Nam[IN]                 Index (base 0) of the NAM
//                                      account to read. See
//                                      SwiGetNamInfo.
//              PrefServ[OUT]           The system preference
//                                      (determined by the service
//                                      provider) from the selected NAM
//                                      account profile:
//                                      0 = System A only
//                                      1 = System B only
//                                      2 = Home only
//                                      3 = Home preferred
//                                      4 = Automatic A
//                                      5 = Automatic B
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The preferred service is set using
//              SwiPstSetSystemPref.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetSystemPref(const SWI_U16 Nam, SWI_U16 *PrefServ, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetSipUserId - Get Simple IP Profile 1
//
// Purpose:     This function returns the Simple IP profile 1
//              (index 0) user ID string.
//
// Parameters:  pszUserId[OUT]          The destination in which the user
//                                      ID string is returned.
//              szLength[IN]            The maximum size of the output
//                                      buffer.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This is not supported on the SB555.
//
//              The user ID is also referred to as the NAI (refer to
//              IS-638B section 3.5.8).
//
//              The maximum length of the user ID string is 72
//              bytes; the minimum is 1.
//
//              The User ID is set using SwiPstSetSipUserId.
//
//              See also SwiPstGetSipPassword.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetSipUserId(SWI_U8 *pszUserId, SWI_U32 szLength, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetSipPassword - Get Simple IP profile 1 password
//
// Purpose:     This function returns the Simple IP profile 1
//              (index 0) user ID string.
//
// Parameters:  pszPassword[OUT]        The destination in which the user
//                                      password is returned.
//              szLength[IN]            The maximum size of the output
//                                      buffer.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This is not supported on the SB555.
//
//              The password is set using SwiPstSetSipPassword.
//              See also SwiPstGetSipUserID.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetSipPassword(SWI_U8 *pszPassword, SWI_U32 szLength, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetDsMipGenUser - Configure Mobile IP profile settings
//
// Purpose:     This function configures various Mobile IP profile settings.
//
// Parameters:  index[IN]               Index # of Profile to modify
//                                      0-5
//              naiLength[IN]           Length of NAI field in bytes
//              nai[IN]                 NAI (username)
//              mnHaSpiEnable[IN]       MN-HA SPI enable
//                                      0 - disable
//                                      1 - enable
//              mnHaSpi[IN]             MN-HA SPI
//              mnAaaSpiEnable[IN]      MN-AAA SPI enable
//                                      0 - disable
//                                      1 - enable
//              mnAaaSpi[IN]            MN-AAA SPI
//              reverseTunneling[IN]    Reverse Tunneling Preferred
//                                      0 - disable
//                                      1 - enable
//              homeAddress[IN]         Home IP Address
//              primaryHaAddress[IN]    Primary HA IP Address (big-endian)
//              secondaryHaAddress[IN]  Secondary HA IP Address (big-endian)
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Supported for only Mobile IP enabled devices.
//              See SwiPstGetDsQcMip for determining MIP capability.
//
//              For more information on the fields, please refer to the 
//              documentation.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetDsMipGenUser(const SWI_U16 index, const SWI_U16 naiLength, SWI_U8 *nai,
		const SWI_U16 mnHaSpiEnable, const SWI_U32 mnHaSpi, 
		const SWI_U16 mnAaaSpiEnable, const SWI_U32 mnAaaSpi,
		const SWI_U16 reverseTunneling, const SWI_U32 homeAddress,
		const SWI_U32 primaryHaAddress, const SWI_U32 secondaryHaAddress, 
		SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetDsMipGenUser - Get Mobile IP profile settings
//
// Purpose:     This function configures various Mobile IP profile settings.
//
// Parameters:  index[IN]               Index # of Profile to retrieve
//                                      0-5
//              timeout[IN]             Function timeout in milliseconds
//              naiLength[OUT]          Length of NAI field in bytes
//              nai[OUT]                NAI (username)
//              pMnHaSpiEnable[OUT]     MN-HA SPI enable
//                                      0 - disable
//                                      1 - enable
//              pMnHaSpi[OUT]           MN-HA SPI
//              pMnAaaSpiEnable[OUT]    MN-AAA SPI enable
//                                      0 - disable
//                                      1 - enable
//              mnAaaSpi[IN]            MN-AAA SPI
//              pMnAaaSpi[OUT]          MN-AAA SPI
//              pReverseTunneling[OUT]  Reverse Tunneling Preferred
//                                      0 - disable
//                                      1 - enable
//              pHomeAddress[OUT]       Home IP Address
//              pPrimaryHaAddress[OUT]  Primary HA IP Address (big-endian)
//              pSecondaryHaAddress[OUT]
//                                      Secondary HA IP Address (big-endian)
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Supported for only Mobile IP enabled devices.
//              See SwiPstGetDsQcMip for determining MIP capability.
//
//              For more information on the fields, please refer to the 
//              documentation.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipGenUser(const SWI_U16 index, SWI_U16 naiLength, SWI_U8 *nai,
		SWI_U16 *pMnHaSpiEnable, SWI_U32 *pMnHaSpi, 
		SWI_U16 *pMnAaaSpiEnable, SWI_U32 *pMnAaaSpi,
		SWI_U16 *pReverseTunneling, SWI_U32 *pHomeAddress,
		SWI_U32 *pPrimaryHaAddress, SWI_U32 *pSecondaryHaAddress, 
		SWI_U32 timeout);

/////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetDsQcMip - Determine Mobile IP (MIP) call support
//
// Purpose:     This function reports the modem's Mobile IP call support
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pBehaviour[OUT]         The destination in which the MIP 
//                                      support is returned:
//                                      0 - Not supported.  Simple IP only.
//                                      1 - MIP Prefered.  (Fallback to SIP if 
//                                                              MIP fails)
//                                      2 - MIP Only.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       See documentation for details on Mobile IP and Simple IP.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsQcMip(SWI_U16 *pBehaviour, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetDsMipActiveProf - Get the active profile for a 
//              Mobile IP call
//
// Purpose:     Gets the active profile in which a Mobile IP call will use
//
// Parameters:  active[IN]              Profile # to set as active.  Supported
//                                      values are 0-5.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This is supported for only Mobile IP enabled modems.
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipActiveProf(SWI_U16* pActive, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetDsMipActiveProf - Set the active profile for a 
//              Mobile IP call
//
// Purpose:     Sets the active profile in which a Mobile IP call will use
//
// Parameters:  active[IN]              Profile # to set as active.  Supported
//                                      values are 0-5.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This is supported for only Mobile IP enabled modems.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetDsMipActiveProf(const SWI_U16 active, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstUnlock - Unlocks access to the activation process.
//
// Purpose:     This function uses the subsidy lock value (OTSL,
//              MSL, or SPC) to unlock access to activate (write)
//              a NAM account profile.  
//
// Parameters:  SubsidyLock[IN]         Either the OTSL, or the MSL (also
//                                      known as the SPC). This number
//                                      is provided by the service provider.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      SWI_RCODE_OK            The lock code was accepted
//                                      and the modem successfully unlocked for
//                                      activation.
//              SWI_RCODE_FAILED        The lock code was rejected or the function 
//                                      failed to process successfully.
//                                      Most cases indicate a rejected lock code.
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout. The modem may in fact become 
//                                      unlocked, but you should retry the 
//                                      command.
//
// Notes:       See Activation process in the API Reference for a description of 
//              the complete activation process.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstUnlock(SWI_U32 SubsidyLock, SWI_U32 timeout); 

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetHomeSidNid - Set home SID and NID
//
// Purpose:     This function sets a table of SID and NID values
//              to be designated as "home" (not roaming).
//
//              The modem must be unlocked via SwiPstUnlock
//              to execute this command.
//
// Parameters:  Nam[IN]                 Index (base 0) of the NAM
//                                      account to set. See
//                                      SwiGetNamInfo.
//              HomeSidNid[IN]          The structure containing the data
//                                      to store. See documentation for
//                                      structure details.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Not all service providers require the user to alter
//              these settings. The current table can be read
//              using SwiPstGetHomeSidNid.
//
//              The data is not committed until SwiPstLock is
//              called. See "Activation process in documentation
//              for a description of the activation process.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetHomeSidNid(const SWI_U16 Nam, const SWI_STRUCT_HomeSidNid *HomeSidNid, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetHomeSidNid - Get home SID and NID
//
// Purpose:     This function returns the table of SID and NID
//              values designated as "home" (not roaming).
//
// Parameters:  Nam[IN]                 Index (base 0) of the NAM
//                                      account to read. See
//                                      SwiGetNamInfo.
//              HomeSidNid[OUT]         The destination structure in which
//                                      the data is returned. See documentation
//                                      for structure details.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       These values are usually preset at the factory for
//              the particular service provider. They can be
//              changed using SwiPstSetHomeSidNid.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetHomeSidNid(const SWI_U16 Nam, SWI_STRUCT_HomeSidNid *HomeSidNid, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetSystemPref - Set preferred service for NAM
//
// Purpose:     This function sets the CDMA preferred service
//              for a specified NAM account profile. This is the
//              fallback channel scan if the PRL is exhausted
//              without finding service.
//
// Parameters:  Nam[IN]                 Index (base 0) of the NAM
//                                      account to set. See
//                                      SwiGetNamInfo.
//              PrefServ[IN]            The system preference to set in
//                                      the selected NAM account profile:
//                                      0 = System A only
//                                      1 = System B only
//                                      2 = Home only
//                                      3 = Home preferred
//                                      4 = Automatic A
//                                      5 = Automatic B
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This value is usually set at the factory for the
//              specific service provider. Only change the
//              setting at the service providers direction. The
//              current setting can be read using
//              SwiPstGetSystemPref. The modem must be reset
//              via SwiResetModem to have the setting take
//              effect.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetSystemPref(const SWI_U16 Nam, const SWI_U16 PrefServ, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetSipUserId - Set Simple IP profile 1 user ID
//
// Purpose:     This function sets the Simple IP profile 1
//              (index 0) user ID string.
//
// Parameters:  pszUserId[IN]           The user ID string to set.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The user ID is also referred to as the NAI (refer to
//              IS-638B section 3.5.8). The current setting can be
//              read using SwiPstGetSipUserID.
//
//              This is only required on the AirCard products
//              because the NDIS interface must exchange this
//              data to create a PPP data connection. The SB555
//              handles this data via DUN.
//
//              The maximum length of the user ID string is 72
//              bytes; the minimum is 1.
//
//              The data is committed and takes effect immedi-ately.
//
//              See also SwiPstSetSipPassword.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetSipUserId(SWI_U8 *szUserId, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetSipPassword - Set Simple IP profile 1 password
//
// Purpose:     This function sets the Simple IP profile 1
//              (index 0) user password string.
//
// Parameters:  pszPassword[IN]         The user password string to store.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This is only required on the AirCard products
//              because the NDIS interface must exchange this
//              data to create a PPP data connection. The SB555
//              handles this data via DUN.
//
//              The current setting can be read using
//              SwiPstGetSipPassword.
//
//              The data is committed and takes effect immedi-ately.
//
//              See also SwiPstSetSipUserId.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetSipPassword(SWI_U8 *szPassword, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstLock - Closes the activation process.          
//
// Purpose:     This function closes the activation process, either
//              cancelling the changes or committing them to
//              storage.  
//              The modem must have been unlocked via
//              SwiPstUnlock prior to this command.
//
// Parameters:  Type[IN]                0 = cancel changes
//                                      1 = commit changes
//              Nam[IN]             	Index (base 0) of the NAM
//                                      account profile to commit or
//                                      cancel. See SwiGetNamInfo.
//              timeout[IN]             Function timeout in milliseconds
//              commitResult[OUT]       0 = Fail - see remarks
//                                      1 = Success
//              failureMask[OUT]        Bit-mapped failure reason, see
//										SWI_TYPE_Commit_ErrorMask for possible values
//
// Return:      SWI_RCODE_OK            The function executed
//                                      normally. The actual result of the process
//                                      is returned in the output parameters.
//              SWI_RCODE_FAILED        The process was not successfully completed. 
//                                      The entire activation process should be 
//                                      redone.
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout. The entire activation process 
//                                      should be redone.
//
// Notes:       In the event of a failure, the entire process of
//              activation should be repeated. The failure mask
//              reports all known reasons why a commit failed.
//              See Activation process in the API Reference for a
//              description of the complete activation process.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstLock(const SWI_U16 Type, const SWI_U16 Nam, SWI_U16 *commitResult, 
                               SWI_U16 *failureMask, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetMinuteCallBeep - Gets the audible minute-alert setting
//
// Purpose:     This function reports the state of the setting for
//              generating an audible beep shortly before the
//              one minute intervals of a voice call.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              callBeep[OUT]           The destination in which the
//                                      beep setting is returned:
//                                      0 = disabled
//                                      1 = enabled
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The value is set using SwiPstSetMinuteCallBeep.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetMinuteCallBeep(SWI_U16 *callBeep, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetMinuteCallBeep - Sets the audible minute-alert setting
//
// Purpose:     This function enables or disables the playing of a
//              beep tone just before the one minute intervals of a voice call.
//
// Parameters:  callBeep[IN]            The beep setting to use:
//                                      0 = disabled
//                                      1 = enabled
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The setting can be read using SwiPstGetMinuteCallBeep.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetMinuteCallBeep(const SWI_U16 callBeep, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetServiceAreaAlert - Gets the Service Area Alert option
//
// Purpose:     This function reports whether the alert tone for
//              changes in service (in or out of coverage)
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              srvAreaAlert[OUT]       The destination in which the
//                                      service alert state is returned:
//                                      0 = disabled
//                                      1 = enabled
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The setting can be changed using SwiPstSetServiceAreaAlert.
//
//              Enables/disables playing an alert tone in the headset when there 
//              is a change in the type of coverage. A call to 
//              SwiGetServiceIndication will confirm the nature of the change 
//              in service.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetServiceAreaAlert(SWI_U16 *srvAreaAlert, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetServiceAreaAlert - Sets the Service Area Alert option
//
// Purpose:     This function enables or disables the playing of a
//              beep tone to alert the user of changes in service
//              while in a voice call.
//
// Parameters:  srvAreaAlert[IN]        The service alert state to set:
//                                      0 = disabled
//                                      1 = enabled
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Enables/disables playing an alert tone in the
//              headset when there is a change in the type of
//              coverage. A call to SwiGetServiceIndication
//              will confirm the nature of the change in service.
//
//              The setting can be read using
//              SwiPstGetServiceAreaAlert.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetServiceAreaAlert(const SWI_U16 srvAreaAlert, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetDsMipSsUserProf - Get Mobile IP profile shared secret 
//                                         passwords
//
// Purpose:     This function retrieves the Home Agent (HA) and AAA shared secret 
//				passwords from a profile (determined by 'index')
//
// Parameters:  index[IN]               Index # of Profile to retrieve
//                                      0-5 Note: index 0 is reserved for IOTA
//
//              mnHaSs[OUT]             HA shared secret password
//              mnHaSsLength[OUT]       Length of HA field in bytes
//              mnHaSsBufLength[IN]		Buffer size
//
//              mnAaaSs[OUT]            AAA shared secret password
//              mnAaaSsLength[OUT]      Length of AAA field in bytes
//              mnAaaSsBufLength[IN]    Buffer size
//
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Supported for only Mobile IP enabled devices.
//              To set the passwords, see SwiPstSetDsMipSsUserProf
//
//              For more information on the fields, please refer to the 
//              documentation.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipSsUserProf(const SWI_U16 index, SWI_U8 *mnHaSs, SWI_U16 *mnHaSsLength, 
									SWI_U16	mnHaSsBufLength, SWI_U8 *mnAaaSs, 
									SWI_U16 *mnAaaSsLength, SWI_U16 mnAaaSsBufLength, SWI_U32 timeout);
									
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetDsMipSsUserProf - Set Mobile IP profile shared secret 
//                                         passwords
//
// Purpose:     This function sets the Home Agent (HA) and AAA shared secret
//				passwords of a Mobile IP profile (determind by 'index')
//
// Parameters:  index[IN]               Index # of Profile to modify
//                                      0-5 Note: index 0 is reserved for IOTA
//
//              mnHaSsLength[IN]        Length of HA field in bytes
//              mnHaSs[IN]              Home Agent shared secret password
//
//              mnAaaSsLength[IN]       Length of AAA field in bytes
//              mnAaaSs[IN]             AAA shared secret password
//
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Supported for only Mobile IP enabled devices.
//              To retrieve the passwords, see SwiPstGetDsMipSsUserProf
//
//              For more information on the fields, please refer to the 
//              documentation.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetDsMipSsUserProf(const SWI_U16 index, const SWI_U16 mnHaSsLength, 
									SWI_U8 *mnHaSs, const SWI_U16 mnAaaSsLength, 
									SWI_U8 *mnAaaSs, SWI_U32 timeout);
									
//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetDsQcMip - Set Mobile IP Mode
//
// Purpose:     This function sets the Mobile IP Mode setting 
//
// Parameters:  behaviour[IN]           The MIP mode behaviour
//                                      0 = SIP only
//                                      1 = MIP Preferred (fallback to SIP 
//                                          if MIP fails)
//                                      2 = MIP only    
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetDsQcMip(const SWI_U16 behaviour, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetAccolc - Get Access Overload Class
//
// Purpose:     This function gets the Access Overload Class setting. 
//
// Parameters:  Nam[IN]                 The NAM requested
//              timeout[IN]             Function timeout in milliseconds
//              Accolc[OUT]             Accolc setting
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetAccolc(const SWI_U16 Nam, SWI_U16 *Accolc, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetAccolc - Set Access Overload Class
//
// Purpose:     This function Sets the Access Overload Class value.
//
// Parameters:  Nam[IN]                 The NAM requested
//              timeout[IN]             Function timeout in milliseconds
//              Accolc[IN]              Accolc setting
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetAccolc(const SWI_U16 Nam, const SWI_U16 Accolc, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetPrefMode - Get Preferred Operating Mode
//
// Purpose:     This function gets the Preferred Operating Mode setting. 
//
// Parameters:  Nam[IN]                 The NAM requested
//              timeout[IN]             Function timeout in milliseconds
//              PrefMode[OUT]           Preferred Mode setting 
//                                      <see SWI_TYPE_NvPrefOpMode>
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetPrefMode(const SWI_U16 Nam, SWI_U16 *PrefMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstSetPrefMode - Set Preferred Operating Mode
//
// Purpose:     This function sets the Preferred Operating Mode value. 
//
// Parameters:  Nam[IN]                 The NAM requested
//              timeout[IN]             Function timeout in milliseconds
//              PrefMode[IN]            Preferred Mode setting
//                                      <see SWI_TYPE_NvPrefOpMode>
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetPrefMode(const SWI_U16 Nam, const SWI_U16 PrefMode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetSci - Get Slot Cycle Index
//
// Purpose:     This function gets the Slot Cycle Index value. 
//
// Parameters:  Sci[IN]                 The Slot cycle index setting
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetSci(SWI_U16 *Sci, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetImsiMS1
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetImsiMS1(const SWI_U16 Nam, SWI_U32 *IMSI, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetImsi1112
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetImsi1112(const SWI_U16 Nam, SWI_U16 *Digits1112, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetImsiMcc
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetImsiMcc(const SWI_U16 Nam, SWI_U16 *Mcc, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetTermSid
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetTermSid(const SWI_U16 Nam, SWI_U16 *TermSidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstSetTermSid
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetTermSid(const SWI_U16 Nam, const SWI_U16 TermSidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetTermNid
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetTermNid(const SWI_U16 Nam, SWI_U16 *TermNidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:   SwiPstSetTermNid   
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstSetTermNid(const SWI_U16 Nam, const SWI_U16 TermNidEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetNamName
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetNamName(const SWI_U16 Nam, SWI_LPCTSTR pszNamName, SWI_U32 length, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipPrereRrqTime
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipPrereRrqTime(SWI_U16* pRereg, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipQcDrsOpt
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipQcDrsOpt(SWI_U16* pActive, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipRetries
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipRetries(SWI_U16* pRetries, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipRetryInt
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipRetryInt(SWI_U16* pInterval, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMipRrqIfTfrk
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMipRrqIfTfrk(SWI_U16* pReregistration, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiPstGetDsMip2002BisMnHaAuth
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDsMip2002BisMnHaAuth(SWI_U16* pRfc2002, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPriGetVoiceDataMask - Get modem's voice/data capabilities
//
// Purpose:     This function reports the modem's voice/data capabilities
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              voiceDataMask[OUT]      The destination in which the
//                                      the data is returned. Possible mask
//                                      bit values are defined in
//                                      SWI_TYPE_PRI_VoiceDataMask
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Modems running with older firmware may not have these values
//              defined, and will return an error.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPriGetVoiceDataMask(SWI_U16 *voiceDataMask, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetStationClassMark - Get Station Class Mark
//
// Purpose:     This function will be used to get the device's Station Class Mark
//				
// Parameters:  
//            pbSCM[OUT]			 Pointer to data buffer
//                          
//            timeout[IN]       Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetStationClassMark(SWI_U8 *pbSCM, SWI_U32 timeout);

#pragma mark
#pragma mark led stuff
#pragma mark

//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiGetLEDEnable 
//
// Purpose: Get the device's LED enable state. 
//
// Parameters:  pbEnable[OUT]                 Current state of LED setting (0=disabled,1=enabled)
//              timeout[IN]                    Api timeout
//
// Return:      See SwiRcodes.h
//              
// Notes:   This functionality is not support on all devices.  A successful return indicates the
//          functionality exists and the current setting of the LED.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLEDEnable(bool *pbEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiSetLEDEnable 
//
// Purpose: Set the device's LED enable state. 
//
// Parameters:  bEnable[OUT]                 LED setting (0=disabled,1=enabled)
//              timeout[IN]                  Api timeout
//
// Return:      See SwiRcodes.h
//              
// Notes:   This functionality is not support on all devices.  A successful return indicates the
//          functionality exists and the LED setting was set.  To determine if feature is supported,
//          use SwiGetLEDEnable().
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLEDEnable(bool bEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiGetLEDEnableEx
//
// Purpose: Get the device's LED enable state. This API extends SwiGetLEDEnable by adding a bit
//          mask for indicating LED groups (ie. pwr/signal and glowtop)
//
// Parameters:  pLED[OUT]                     Table of LEDs types and settings 
//                                            <see SWI_TYPE_LED_TYPE for type defintions>
//
//              timeout[IN]                   Api timeout
//
// Return:      See SwiRcodes.h
//             
// Notes:   This functionality is not support on all devices.  Check SwiGetGeneralFeatureSupport()
//          for SWI_GEN_FEATURE_ENH_LED to determine if enhanced LED support is available.  If so,
//          this API must be used in place of SwiGetLEDEnable().
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetLEDEnableEx(SWI_TYPE_LED_CFG_ENABLE *pLED, SWI_U32 timeout);
 
//////////////////////////////////////////////////////////////////////////////////
//
// Name: SwiSetLEDEnableEx
//
// Purpose: Set the device's LED enable states. This API extends SwiSetLEDEnable by adding a bit
//          mask to control LED groups.
//
// Parameters:  pLED[IN]                      Table of LED settings
//                                            0 = disable, 1 = enable
//                                            Note: Type field is not used.
//
//              timeout[IN]                   Api timeout
//
// Return:      See SwiRcodes.h
//             
// Notes:   This functionality is not support on all devices.  A successful return indicates the
//          functionality exists and the LED setting was set.  To determine if feature is supported,
//          check for SWI_GEN_FEATURE_ENH_LED using SwiGetGeneralFeatureSupport(). If supported, this
//          API must be used in place of SwiSetLEDEnable().
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetLEDEnableEx(const SWI_TYPE_LED_CFG_ENABLE *pLED, SWI_U32 timeout);

#pragma mark
#pragma mark Warranty Date Code
#pragma mark

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetWarDateCode - Get Warranty Date Code (Refurbish Date)
//
// Purpose:     This function is used to get the warranty date code.  Note that the character
//				data returned is not NULL terminated.
//				
// Parameters:  
//				warrantyString[OUT]		Pointer to char (byte) array containing warranty date chars
//				lenghWarranty[IN]		Length of pszWarranty (should be set to 5)
//				extraDate[OUT]			Pointer to char (byte) array containing Extra date chars
//				lengthExtra[IN]			Length of pszExtra (should be 3)
//			 	timeout[IN]				Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetWarDateCode(SWI_LPCTSTR warrantyString, SWI_U32 lengthWarranty, SWI_LPTSTR extraDate, SWI_U32 lengthExtra, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPstGetDisplayBannerName - Get display name
//
// Purpose:     This function is used to get the GUI TEXT display value.
//				
// Parameters:  
//				displayBannerName[OUT]			Pointer to char (byte) array containing gui text display value
//				displayBannerNameLength[IN]		Length of displayBannerName
//			 	timeout[IN]						Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPstGetDisplayBannerName (SWI_LPTSTR displayBannerName, SWI_U32 displayBannerNameLength, SWI_U32 timeout);

enum SWI_TYPE_General_Features
{
  SWI_GEN_FEATURE_IOTA_2_4    = 0x00000001,
  SWI_GEN_FEATURE_ENH_GPS     = 0x00000002,
  SWI_GEN_FEATURE_ENH_LED     = 0x00000004,                    //New
  SWI_GEN_FEATURE_RESERVED3   = 0x00000008,
  SWI_GEN_FEATURE_RESERVED4   = 0x00000010,
  SWI_GEN_FEATURE_RESERVED5   = 0x00000020,
  SWI_GEN_FEATURE_RESERVED6   = 0x00000040,
  SWI_GEN_FEATURE_RESERVED7   = 0x00000080,
  SWI_GEN_FEATURE_RESERVED8   = 0x00000100,
  SWI_GEN_FEATURE_RESERVED9   = 0x00000200,
  //remaining bits reserved for future feature definitions...
};
 

#pragma mark -

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetMipSessionNai 
//
// Purpose:     Sets MIP User name for one session.  This is applied to the
//              currently active MIP profile.  This command updates RAM copy of MIP
//              user name and is not saved in NV memory.  When host sends Set
//              Request with payload length of zero, RAM copy of MIP user name is
//              cleared and the credentials stored in NV are used for the next data
//              call.  However, modem automatically clears RAM values when data
//              session is torn down or if MIP session set up fails
//
// Parameters:  nai[IN]         pointer to NULL terminated string containing username
//              timeout[IN]     API timeout
//
// Return:      See SwiRcodes.h
//
// Notes:
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetMipSessionNai( SWI_U8 const * const nai, SWI_U32 timeout );

#pragma mark -
	
//**********************************************************************************
//	SwiGetPSTData
//		This call returns all the PST data in one structure
//		the primary use is to check all the "GET" calls for
//		PST
//**********************************************************************************
typedef struct
{
	SWI_RCODE				_ret[34];
	
	SWI_U16					_NAM;
	
	SWI_U8						_nai[CHAR_64];
	SWI_U16						_mnHaSpiEnable;
	SWI_U32						_mnHaSpi;
	SWI_U16						_mnAaaSpiEnable;
	SWI_U32						_mnAaaSpi;
	SWI_U16						_reverseTunneling;
	SWI_U32						_homeAddress;
	SWI_U32						_primaryHaAddress;
	SWI_U32						_secondaryHaAddress;
	SWI_U32						_IMSI01;
	SWI_U16						_IMSI02;
	SWI_U16						_Digits1112;
	SWI_U16						_Mcc;
	SWI_U16						_TermSidEnable;
	SWI_U16						_TermNidEnable;
	SWI_U8						_pszNamName[CHAR_64];
	SWI_U16						_pReregTime;
	SWI_U16						_pRereg;
	SWI_U16						_pRetries;
	SWI_U16						_pInterval;
	SWI_U16						_pReregistration;
	SWI_U16						_pRfc2002;
	SWI_STRUCT_MipEnabled	_sMipEnabled;
	SWI_U16						_CurrentNam;
	SWI_U16						_PrefServ;
	SWI_U8						_pszUserId[CHAR_64];
	SWI_U8						_pszPassword[CHAR_64];
	SWI_U16						_pBehaviour;
	SWI_U16						_pActive;
	SWI_STRUCT_HomeSidNid	_HomeSidNid;
	SWI_U16						_callBeep;
	SWI_U16						_srvAreaAlert;
	
	SWI_U8					_mnHaSs[CHAR_64];
	SWI_U16						_mnHaSsLength;
	//SWI_U16	mnHaSsBufLength
	SWI_U8					_mnAaaSs[CHAR_64];
	SWI_U16					_mnAaaSsLength;
	//SWI_U16 mnAaaSsBufLength
	
	SWI_U16						_Accolc;
	SWI_U16						_PrefMode;
	SWI_U16						_Sci;
	SWI_U32						_IMSI;
	SWI_U8						_pbUsesSCP;
	SWI_U16						_pwCustCfgActive;
	SWI_U32						_pdwProtMask;
	SWI_U32						_pdwBCMCSMask;
	SWI_U32						_pdwAppMask;
	
	SWI_U32						_pMask;
	
	SWI_U8					_scm;
	
	SWI_U8						_securityLockCode[16];
	
	SWI_U8					_ledStatus;
	
} PST_DATA;



SWI_RCODE SwiGetPSTData(PST_DATA *data);

#ifdef __cplusplus
}
#endif

#endif // __SWIMACPST__


