/*
 *  swiwimax.h
 *  swimac
 *
 *  Created by Mark de Jong on 10/21/09.
 *  Copyright 2009 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWI_WIMAX_H
#define __SWI_WIMAX_H

#include "swimacstructs.h"

#ifdef __cplusplus
extern "C"	{
#endif

#pragma mark -
#pragma mark Constants / Defines
	// ********************************************************************************
	// Constants / Defines
	// ********************************************************************************
	#define LENGTH_MAX_4G_String 125

#pragma mark -
#pragma mark Enumerations
	// ********************************************************************************
	// Enumerations
	// ********************************************************************************
	typedef enum
	{
		SWI_WAN_MODE_CDMA_ONLY,				//0x00
		SWI_WAN_MODE_WIMAX_ONLY,			//0x01	// Default
		SWI_WAN_MODE_AUTOMATIC,				//0x02
		SWI_WAN_MODE_MAX					= 0xff,
	} SWI_TYPE_WAN_MODE;

	typedef enum
	{
		SWI_WAN_MODE_PREF_CDMA,				//0x00
		SWI_WAN_MODE_PREF_WIMAX,			//0x01
		SWI_WAN_MODE_PREF_MAX				= 0xff,
	} SWI_TYPE_WAN_MODE_PREF;

	typedef enum
	{
		OMADM_WORKMODE_UNPROVISIONED,		//0x00
		OMADM_WORKMODE_CDMA_ONLY,			//0x01
		OMADM_WORKMODE_WIMAX_CDMA,			//0x02
		OMADM_WORKMODE_MAX					= 0xff,
	} SWI_TYPE_OMADM_WORKMODE;

	typedef enum
	{
		SWI_DEVICE_MODE_SINGLE_CDMA,		//0x00
		SWI_DEVICE_MODE_DUAL_WIMAX_CDMA,	//0x01
		SWI_DEVICE_MODE_MAX					= 0xff,
	} SWI_TYPE_DEVICE_MODE;

	typedef enum
	{
		SWI_WIMAX_OP_MODE_OFF,							//0x00
		SWI_WIMAX_OP_MODE_SEARCHING_SLEEP,				//0x01
		SWI_WIMAX_OP_MODE_FULL_POWER_SEARCHING_ACTIVE,	//0x02
		SWI_WIMAX_OP_MODE_SEARCHING_ACTIVE = SWI_WIMAX_OP_MODE_FULL_POWER_SEARCHING_ACTIVE,	//0x02 - this label/enum has been deprecated
		SWI_WIMAX_OP_MODE_ACQUIRED,						//0x03
		SWI_WIMAX_OP_MODE_CONNECT,						//0x04
		SWI_WIMAX_OP_MODE_LOW_POWER_SEARCHING_ACTIVE,	//0x05
	} SWI_TYPE_WIMAX_OP_MODE;

	typedef enum
	{
		SWI_4G_AUTH_METHOD_TLS				= 13,
		SWI_4G_AUTH_METHOD_TTLS				= 21,
		SWI_4G_AUTH_METHOD_MAX				= 0xff,
	} SWI_TYPE_4G_AUTH_METHOD;

#pragma mark -
#pragma mark Data structures
	// ********************************************************************************
	// Data structures
	// ********************************************************************************
	typedef struct
	{
		SWI_U16	iWimaxIdleSleep;				// seconds; range: 5-300
		
		SWI_S16 iWimaxEntryRssi;				// dBm; range: -130 to -60 (signed)
		SWI_U16	iWimaxEntryCinr;				// dBm; range: 0-20
		SWI_U16	iWimaxEntryDelay;				// seconds; range: 0-600
		
		SWI_S16 iWimaxExitRssi;					// dBm; range: -130 to -60 (signed)
		SWI_U16	iWimaxExitCinr;					// dBm; range: 0-20
		SWI_U16	iWimaxExitDelay;				// seconds; range: 0-600
		
		SWI_S16 iCdmaEntryRssi;					// dBm; range: -130 to -60 (signed)
		SWI_U16	iCdmaEntryDelay;				// seconds; range: 0-600
		
		SWI_S16 iCdmaExitRssi;					// dBm; range: -130 to -60 (signed)
		SWI_U16	iCdmaExitDelay;					// seconds; range: 0-600
	} SWI_STRUCT_NET_ENTRY_EXIT;

	typedef struct 
	{
		SWI_U32	sizeStruct;
		
		SWI_U8	last_connected_state;	// if device was connected or idle when host last talked to it
		SWI_U8	last_active_rat;			// what was last active technology
	} SWI_STRUCT_4GSSV;
	
#pragma mark -
#pragma mark Function Declarations
	// ********************************************************************************
	// Function Declarations
	// ********************************************************************************

	/*	********************************************************************************
	 *	Function:	SwiGetOMADMWorkMode
	 *
	 *	Arguments:	workMode [OUT]	Enum containing current provisioning state of the
	 *								device.
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Returns whether how device is provisioned.
	 */
	SWI_RCODE SwiGetOMADMWorkMode( SWI_TYPE_OMADM_WORKMODE *workMode, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiGetDeviceMode
	 *
	 *	Arguments:	deviceMode [OUT]	Enum containing current device mode.
	 *				timeout [IN]		Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Returns whether the device is in "singal" (CDMA) or "dual"
	 *				(CDMA/WiMAX) mode.
	 */
	SWI_RCODE SwiGetDeviceMode( SWI_TYPE_DEVICE_MODE *deviceMode, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiGetWanMode
	 *
	 *	Arguments:	wanMode [OUT]	Enum containing current WAN mode.
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Get the current WAN mode.
	 */
	SWI_RCODE SwiGetWanMode( SWI_TYPE_WAN_MODE *wanMode, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiSetWanMode
	 *
	 *	Arguments:	newWanMode [IN]	Enum containing desired WAN mode.
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Set the WAN mode.
	 */
	SWI_RCODE SwiSetWanMode( SWI_TYPE_WAN_MODE newWanMode, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiGetWanModePref
	 *
	 *	Arguments:	wanModePref [OUT]	Enum containing user preferred WAN mode.
	 *				timeout [IN]		Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Return the user preferred WAN mode.
	 */
	SWI_RCODE SwiGetWanModePref( SWI_TYPE_WAN_MODE_PREF *wanModePref, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiSetWanModePref
	 *
	 *	Arguments:	newWanModePref [IN]	Enum containing user preferred WAN mode.
	 *				timeout [IN]		Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Set the user preferred WAN mode.
	 */
	SWI_RCODE SwiSetWanModePref( SWI_TYPE_WAN_MODE_PREF newWanModePref, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiGetWimaxOperatingMode
	 *
	 *	Arguments:	currentMode [OUT]	Enum describing the current  WiMAX operating
	 *									mode
	 *				timeout [IN]		Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Returns the current WiMAX operating mode.
	 */
	SWI_RCODE SwiGetWimaxOperatingMode( SWI_TYPE_WIMAX_OP_MODE *currentMode, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiSetWimaxOperatingMode
	 *
	 *	Arguments:	newMode [IN]		Enum describing the intended WiMAX operating
	 *									mode
	 *				timeout [IN]		Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Notify modem of intended WiMAX operation. A successful return
	 *				indicates that the WiMAX modem is processing the request. When it
	 *				has completed setting the change, the modem will issue a notification
	 *				(SWI_NOTIFY_WIMAX_Operating_Mode)
	 *				as well as number of scan retries. This item defaults to carrier and
	 *				Sierra Wireless recommended settings.
	 */
	SWI_RCODE SwiSetWimaxOperatingMode( SWI_TYPE_WIMAX_OP_MODE newMode, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiGetNetEntryExit
	 *
	 *	Arguments:	entryExit [OUT]	Structure containing network entry and exit
	 *				parameters.
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Return the network entry and exit criteria along with timeout values
	 *				as well as number of scan retries. This item defaults to carrier and
	 *				Sierra Wireless recommended settings.
	 */
	SWI_RCODE SwiGetNetEntryExit( SWI_STRUCT_NET_ENTRY_EXIT *entryExit, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiSetNetEntryExit
	 *
	 *	Arguments:	entryExit [IN]	Structure containing new network entry and exit
	 *				parameters.
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 *	Return:		SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Set the network entry and exit criteria along with timeout values
	 *				as well as number of scan retries.
	 */
	SWI_RCODE SwiSetNetEntryExit( SWI_STRUCT_NET_ENTRY_EXIT entryExit, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiSetWimaxReset
	 *
	 *	Arguments:	timeout [IN]	Function timeout in milliseconds
	 *
	 *	Returns:	SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Issue a reset request to the WiMAX modem.
	 */
	SWI_RCODE SwiSetWimaxReset( SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiGet4GSSV
	 *
	 *	Arguments:	ssv [OUT]		Structure containing host parameters
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 *	Returns:	SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Return host parameters indicating last connected state and last
	 *				active technology.
	 */
	SWI_RCODE SwiGet4GSSV( SWI_STRUCT_4GSSV *ssv, SWI_U32 timeout );

	/*	********************************************************************************
	 *	Function:	SwiSet4GSSV
	 *
	 *	Arguments:	ssv [IN]		Structure containing host parameters
	 *				timeout [IN]	Function timeout in milliseconds
	 *
	 *	Returns:	SWI_RCODE - See swimacrcodes.h
	 *
	 *	Discussion:	Set host parameters indicating last connected state and last
	 *				active technology.
	 */
	SWI_RCODE SwiSet4GSSV( SWI_STRUCT_4GSSV *ssv, SWI_U32 timeout );
	
#ifdef __cplusplus
}
#endif

#endif // __SWI_WIMAX_H